@@ -18,14 +18,42 @@ from functools import wraps
 
 # region [Constants]
 
-__updated__ = '2020-10-14 20:30:23'
+__updated__ = '2020-11-01 21:25:58'
 
 
 # endregion [Constants]
 
+# region[Global_Functions]
+
+def pathmaker(first_segment, *in_path_segments, rev=False):
+    """
+    Normalizes input path or path fragments, replaces '\\\\' with '/' and combines fragments.
+
+    Parameters
+    ----------
+    first_segment : str
+        first path segment, if it is 'cwd' gets replaced by 'os.getcwd()'
+    rev : bool, optional
+        If 'True' reverts path back to Windows default, by default None
+
+    Returns
+    -------
+    str
+        New path from segments and normalized.
+    """
+    _first = os.getcwd() if first_segment == 'cwd' else first_segment
+    _path = os.path.join(_first, *in_path_segments)
+    _path = _path.replace('\\\\', '/')
+    _path = _path.replace('\\', '/')
+    if rev is True:
+        _path = _path.replace('/', '\\')
+
+    return _path.strip()
+# endregion[Global_Functions]
 
 # region [Logging_Messages]
 
+
 def imported(in_name):
     return (f"succesfully imported [-{in_name}-]")
 
@@ -105,15 +133,15 @@ def main_logger_stdout(in_level, message_sep: int = 10):
 def std_namer(name):
     _nameparts = name.split('.')
     _path, _basename = _nameparts[0].rsplit('\\', 1)
-    return f'{_path}/old_logs/{_basename}_{_nameparts[2]}.{_nameparts[1]}'
+    return pathmaker(_path, 'old_logs', f'{_basename}_{_nameparts[2]}.{_nameparts[1]}')
 
 
-def log_folderer(in_log_file_name, in_main_log_folder='logs', in_old_log_subfolder='old_logs'):
-    _cwd = os.getcwd()
-    _path_to_old_folder = f"{_cwd}/{in_main_log_folder}/{in_old_log_subfolder}"
+def log_folderer(in_log_file_name, in_main_log_folder='logs', in_log_folder_directory=None):
+    _cwd = pathmaker(os.getcwd()) if in_log_folder_directory is None else pathmaker(in_log_folder_directory)
+    _path_to_old_folder = pathmaker(_cwd, in_main_log_folder, 'old_logs')
     if os.path.exists(_path_to_old_folder) is False:
         os.makedirs(_path_to_old_folder)
-    return f"{_cwd}/{in_main_log_folder}/{in_log_file_name}.log"
+    return pathmaker(_cwd, in_main_log_folder, in_log_file_name + ".log")
 
 
 def log_args(function):
